@@ -3,6 +3,8 @@
 #include <Rcpp.h>
 #include <RcppParallel.h>
 
+#include <numeric>
+
 #include "summary_stats.h"
 #include "pillar_utils.h"
 
@@ -10,6 +12,44 @@ using namespace Rcpp;
 using namespace RcppParallel;
 
 
+struct SumPillars : public Worker {
+
+  RVector<double> arr3d;
+  RVector<int> arr3d_dim;
+
+  RMatrix<double> output;
+
+  SumPillars(NumericVector arr3d, IntegerVector arr3d_dim,
+             NumericMatrix output) :
+    arr3d(arr3d), arr3d_dim(arr3d_dim), output(output) {}
+
+  void operator()(std::size_t begin, std::size_t end) {
+    std::size_t nrow = arr3d_dim[0];
+    for (std::size_t p = begin; p != end; ++p) {
+      size_t row = p % nrow;
+      size_t col = p / nrow;
+      std::vector<double> pillar_p =
+        extract_pillar<double>(arr3d, arr3d_dim, p);
+      output(row, col) = std::accumulate(pillar_p.begin(), pillar_p.end(), 0.0);
+    }
+  }
+};
+
+// [[Rcpp::export]]
+NumericMatrix sum_pillars_(NumericVector arr3d) {
+
+  IntegerVector arr3d_dim = arr3d.attr("dim");
+
+  NumericMatrix output(arr3d_dim[0], arr3d_dim[1]);
+
+  SumPillars sumPillars(arr3d, arr3d_dim, output);
+
+  parallelFor(0, arr3d_dim[0] * arr3d_dim[1], sumPillars);
+
+  return output;
+}
+
+
 struct MeanPillars : public Worker {
 
   RVector<double> arr3d;
